@@ -1,6 +1,6 @@
-#!/bin/sh
+#!/bin/bash
 #
-# $Id: chk_ff_2836.sh 870 2013-10-07 18:21:50Z rjc $
+# $Id: chk_ff_2836.sh 974 2014-07-28 16:03:19Z rjc $
 #
 # canonical test suite for fourfit
 #
@@ -12,21 +12,18 @@ verb=false
 ${HOPS_SETUP-'false'} || . $srcdir/chk_env.sh
 export DATADIR=`cd $srcdir/testdata; pwd`
 
-[ -n "$DISPLAY" ] || { echo Skipping test--DISPLAY is undefined; exit 0; }
-
 os=`uname -s` || os=idunno
 grep -v $os $DATADIR/2836/cf2836 > ./cf2836
 
+rm -f ff-2836.ps
 $verb && echo \
-fourfit -pt -b AE:X \\ && echo \
+fourfit -t -d diskfile:ff-2836.ps -b AE:X \\ && echo \
     -c ./cf2836 \\ && echo \
     $DATADIR/2836/scan001/2145+067.olomfh
 
-( echo sff-2836.ps; echo q ) | (
-    fourfit -pt -b AE:X \
-	-c ./cf2836 \
-	$DATADIR/2836/scan001/2145+067.olomfh
-) 2>/dev/null 1>&2
+fourfit -t -d diskfile:ff-2836.ps -b AE:X \
+    -c ./cf2836 \
+    $DATADIR/2836/scan001/2145+067.olomfh 2>/dev/null 1>&2
 
 # pluck out line containing the snr and parse it
 line=$(grep '7570 9653' ./ff-2836.ps)
@@ -35,11 +32,12 @@ IFS='()'
 read a snr b <<<"$line"
 
 # snr bounds
-low=139.1
-high=140.1
+low=139.9
+high=140.9
 aok=$(echo "$snr>$low && $snr<$high" | bc)
+$verb && echo aok is $aok and "$low < $snr < $high" is expected from: $line
 
-[ $aok -gt 0 ]
+[ "$aok" -gt 0 ]
 
 #
 # eof
