@@ -87,6 +87,7 @@ struct c_block                     /* Elemental control block structure */
    char *psamplers[MAX_SAMP];      // pointer to each sampler string (or NULL)
    char sampler_codes[256];        // contains all sampler strings
    int interpolator;               // interpolation method
+   int mbd_anchor;                 // mbd ambiguity choice: model or sbd
    struct dstats station_delay;    // station delay pc inject->digitizer (s)
    struct dstats pc_delay_l;       // delay diff (feed->inject)-(pulsegen->inject) (s)
    struct dstats pc_delay_r;       // same, but for RCP (or Y or V)
@@ -123,7 +124,10 @@ struct c_block                     /* Elemental control block structure */
 #define NULLCHAR  0                /*   "     "     "   "    "     char       "  */
 
                                    // interpolation methods
-#define ITERATE 0
-#define SIMUL 1
+#define ITERATE 1
+#define SIMUL   2
+                                   // mbd anchor choice
+#define MODEL 1
+#define SBD   2
 
 #endif
