@@ -131,6 +131,9 @@ struct c_block *f,*t;               // f (from) is source pointer
     if (f->fmatch_bw_pct != NULLFLOAT)
         t->fmatch_bw_pct = f->fmatch_bw_pct;
 
+    if (f->mbd_anchor != NULLINT)
+        t->mbd_anchor = f->mbd_anchor;
+
     if (f->nsamplers != NULLINT)
         {
         t->nsamplers = f->nsamplers;
