@@ -31,7 +31,7 @@ struct type_208 *t208)
     extern struct mk4_sdata sdata[]; 
     struct mk4_sdata *refsd, *remsd;
     double adelay, arate, aaccel, temp, adelay_ref, arate_ref;
-    double apphase_ref, ref_stn_delay;
+    double apphase_ref, ref_stn_delay, ambig;
     char qcode, errcode, tqcode[6];
 
     clear_208 (t208);
@@ -59,12 +59,21 @@ struct type_208 *t208)
                                         /* Totals, residuals, and errors */
     t208->tot_mbd = t208->adelay + status->mbd_max_global;
     t208->tot_sbd = t208->adelay + status->sbd_max;
+                                        // anchor total mbd to sbd if desired
+    ambig = 1.0 / status->freq_space;
+    if (param->mbd_anchor == SBD)
+        t208->tot_mbd += ambig * floor ((t208->tot_sbd - t208->tot_mbd) / ambig + 0.5);
+
     t208->tot_rate = t208->arate + status->corr_dr_max;
                                         /* ref. stn. time-tagged observables are
                                          * approximated by combining retarded a prioris
                                          * with non-retarded residuals */
     t208->tot_mbd_ref  = adelay_ref * 1e6 + status->mbd_max_global;
     t208->tot_sbd_ref  = adelay_ref * 1e6 + status->sbd_max;
+                                        // anchor ref mbd as above
+    if (param->mbd_anchor == SBD)
+        t208->tot_mbd_ref += ambig 
+                           * floor ((t208->tot_sbd_ref - t208->tot_mbd_ref) / ambig + 0.5);
     t208->tot_rate_ref = arate_ref * 1e6 + status->corr_dr_max;
     
     t208->resid_mbd = status->mbd_max_global;
@@ -93,6 +102,7 @@ struct type_208 *t208)
     status->apphase = fmod (param->ref_freq * t208->adelay * 360.0, 360.0);
     t208->totphase = fmod (status->apphase + status->coh_avg_phase
                         * (180.0/M_PI) , 360.0);
+    msg ("residual phase %f", 1, status->coh_avg_phase * (180.0/M_PI));
                                         /* Ref stn frame apriori delay usec */
     adelay_ref *= 1.0e6;
                                         /* ref_stn_delay in sec, rate in usec/sec */
